from __future__ import annotations

import logging
from typing import (
    Any,
    List,
)

from pydantic import BaseModel

from transwarp_embedding_hub.embedding_hub import *

from langchain.embeddings.base import Embeddings

logger = logging.getLogger(__name__)

with open('config.yaml', 'r') as file:
    data = yaml.safe_load(file)
    embedding_config = data.get('embedding', {})


class AzureEmbedding(BaseModel, Embeddings):

    def embed_documents(self, texts: List[str]) -> List[List[float]]:
        list = []
        for text in texts:
            list.append(self.embed_query(text))
        return list

    def embed_query(self, text: str) -> List[float]:
        openai.api_type = embedding_config.get("azure").get("openai_api_type")
        openai.api_key = embedding_config.get("azure").get("openai_api_key")
        openai.api_base = embedding_config.get("azure").get("openai_api_base")
        openai.api_version = embedding_config.get("azure").get("openai_api_version")
        result = openai.Embedding.create(
            input=text,
            engine=embedding_config.get("azure").get("deployment_name"))["data"][0]["embedding"]
        return result
