import openai
from langchain.embeddings import OpenAIEmbeddings
from transwarp_hippo_langchain.embedding_hub_langchain import *

from azure_embedding import AzureEmbedding

with open('config.yaml', 'r') as file:
    data = yaml.safe_load(file)
    embedding_config = data.get('embedding')
class EmbeddingFactory:

    @staticmethod
    def create(name):
        if name == "openai":
            params = {
                "openai_api_key": embedding_config.get(name).get("openai_api_key"),
                "model_name": embedding_config.get(name).get("model_name")
            }
            return OpenAIEmbeddingsFactory.create(params)
        elif name == "azure":
            return AzureEmbeddingFactory.create()
        else:
            raise ValueError(f"Invalid name: {name}")


class OpenAIEmbeddingsFactory:

    @staticmethod
    def create(params: dict):
        openai_api_key = params.get("openai_api_key")
        model_name = params.get("model_name")
        return OpenAIEmbeddings(openai_api_key=openai_api_key,
                                model=model_name)

class AzureEmbeddingFactory:
    @staticmethod
    def create():
        return AzureEmbedding()
