import json

import openai
import yaml
from langchain import requests, OpenAI
from langchain.chat_models import AzureChatOpenAI, ChatOpenAI

with open('config.yaml', 'r') as file:
    data = yaml.safe_load(file)
    llm_config = data.get('llm', {})


class LLMFactory:

    @staticmethod
    def create(name):
        if name == "azure":
            # 读config
            params = {
                "openai_api_base": llm_config.get(name).get("openai_api_base"),
                "openai_api_key": llm_config.get(name).get("openai_api_key"),
                "deployment_name": llm_config.get(name).get("deployment_name"),
                "openai_api_version": llm_config.get(name).get("openai_api_version"),
                "openai_api_type": llm_config.get(name).get("openai_api_type"),
                "temperature": llm_config.get(name).get("temperature")
            }
            return AzureChatOpenAIFactory.create(params)
        elif name == "openai":
            # 读config
            params = {
                "openai_api_key": llm_config.get(name).get("openai_api_key"),
                "temperature": llm_config.get(name).get("temperature"),
                "model_name": llm_config.get(name).get("model_name")
            }
            return ChatOpenAIFactory.create(params)
        else:
            raise ValueError(f"Invalid name: {name}")


class AzureChatOpenAIFactory:

    @staticmethod
    def create(params: dict):
        openai_api_base = params.get('openai_api_base')
        openai_api_key = params.get('openai_api_key')
        deployment_name = params.get('deployment_name')
        openai_api_version = params.get('openai_api_version')
        openai_api_type = params.get("openai_api_type")
        temperature = params.get('temperature')
        return AzureChatOpenAI(
            openai_api_base=openai_api_base,
            openai_api_version=openai_api_version,
            deployment_name=deployment_name,
            openai_api_key=openai_api_key,
            openai_api_type=openai_api_type,
            temperature=temperature
        )


class ChatOpenAIFactory:

    @staticmethod
    def create(params):
        openai.api_key
        openai_api_key = params.get('openai_api_key')
        temperature = params.get('temperature')
        model_name = params.get('model_name')
        # os.environ["OPENAI_API_KEY"] = openai_api_key
        return ChatOpenAI(
            openai_api_key=openai_api_key,
            temperature=temperature,
            model_name=model_name
        )
